{ nix-flatpak, lib, pkgs, inputs, ... }:
{

  nixpkgs.config.allowUnfree = true;

  home = {
    packages = with pkgs; [
      gnupg
      eza
      just
      fd
      fzf
      bat
      jq
      yt-dlp
      htop
      ripgrep
      erdtree
      age
      figlet
      ffmpeg
      rlwrap
      pinentry
      #unrar
      gnutar
      unzip
      zip
      htop
      opendrop
      owl
      pass
      dconf

      gcc
      gnutls
      gettext
      xorg.libX11
      freetype.dev
      gnumake
      flex
      bison
      mesa

      sane-airscan
      xsane
      opencl-headers
      opencl-clang
      pcapc
      pcsclite
      dbus
      xsane
      libusb1
      v4l-utils
      libgphoto2
      gphoto2
      pulseaudio.dev
      gst_all_1.gstreamer
      alsa-oss
      fontconfig
      vulkan-headers
      vulkan-utility-libraries

      usbutils
      pciutils
      util-linux
      coreutils
      libgcc
      raylib
      SDL2.dev
      protonplus

      ruby
      janet
      jpm
      python3
      python311Packages.pip
      sbcl
      nodejs_18
      platformio-core
      real_time_config_quick_scan

      borgmatic
      kanata-with-cmd
      wezterm 
      lazygit
      nnn
      icloudpd
      jetbrains-mono

      fishPlugins.foreign-env
      fishPlugins.z
      fishPlugins.fzf
      fishPlugins.bass
      fishPlugins.autopair

      via
      bitwarden-cli
      bitwarden-desktop
      rbw
      tailscale
      protonplus

      gnomeExtensions.just-perfection
      #gnomeExtensions.dash-to-dock
      #gnomeExtensions.pano
      gnome-software
      gnome-tweaks
      gnome-photos
      colloid-gtk-theme
      colloid-icon-theme
      whitesur-gtk-theme
      whitesur-cursors
      whitesur-icon-theme
      graphite-gtk-theme
      graphite-cursors
      papers
      newsflash

      wineWowPackages.stagingFull
      wineWowPackages.fonts
      winetricks
      # heroic

      spice
      spice-gtk
      spice-protocol
      virt-viewer

      nyxt
      librewolf
      ungoogled-chromium
      obsidian
      vlc
      polychromatic
      discord
      slack
      signal-desktop
      libreoffice
      plexamp
      carla
      audacity
      supercollider-with-plugins
      bitwig-studio
      blender
      davinci-resolve-studio
      steam
      zotero_7
      handbrake
      renoise
      yabridge
      yabridgectl
      ansel
      rawtherapee
      inkscape
      gimp

      epson-escpr

      # Audio plugins (LV2, VST2, VST3, LADSPA)
      distrho
      calf
      eq10q
      lsp-plugins
      x42-plugins
      x42-gmsynth
      dragonfly-reverb
      guitarix
      FIL-plugins
      geonkick
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    sessionPath = [ "/home/emenel/.config/emacs/bin"
                    "/home/emenel/.config/fish/functions" ];

    sessionVariables = {
      EDITOR = "emacsclient -r";
      WINEFSYNC = 1;
    };

    stateVersion = "24.05";
  };

  home.pointerCursor = {
    gtk.enable = true;
    package = pkgs.vanilla-dmz;
    name = "Vanilla-DMZ";
  };

  programs = {
    home-manager.enable = true;

    direnv = {
      enable = true;
      #enableFishIntegration = true; # see note on other shells below
      nix-direnv.enable = true;
    };
    fish = {
      enable = true;
      shellAliases = {
        "ls" = "eza";
      };
    };
    starship = {
      enable = true;
      enableFishIntegration = true;
    };
    mu.enable = true;
    mbsync.enable = true;
    msmtp.enable = true;
    emacs = {
      enable = true;
      package = pkgs.emacs;
      extraPackages = epkgs: [
        epkgs.mu4e
        epkgs.vterm
      ];
    };
  };

  dconf.settings = {
    "org/gnome/shell/keybindings" = {
      shift-overview-up = ["disabled"];
      shift-overview-down = ["disabled"];
      switch-to-application-1 = ["disabled"];
      switch-to-application-2 = ["disabled"];
      switch-to-application-3 = ["disabled"];
      switch-to-application-4 = ["disabled"];
      switch-to-application-5 = ["disabled"];
      switch-to-application-6 = ["disabled"];
      switch-to-application-7 = ["disabled"];
      switch-to-application-8 = ["disabled"];
      switch-to-application-9 = ["disabled"];
      switch-to-application-10 = ["disabled"];
    };
  };

  nixpkgs.config.packageOverrides = pkgs: {
    renoise = pkgs.renoise.override {
      releasePath = /home/emenel/temp/rns_344_linux_x86_64.tar.gz;
    };
  };

  services = {
    flatpak.enable = true;
  };

  xdg.systemDirs.data = [
    "/home/emenel/.local/share/applications/wine/Programs"
    "/home/emenel/.local/share/applications"
    "/var/lib/flatpak/exports/share"
    "/home/emenel/.local/share/flatpak/exports/share"
    "/home/emenel/.nix-profile/share/applications"
  ];

  services.flatpak.packages = [
    "io.github.zen_browser.zen"
    "com.github.johnfactotum.QuickLookup"
  ];

  xdg.configFile."kmonad".source = ../dotfiles/dot_config/kmonad;
  xdg.configFile."just".source = ../dotfiles/dot_config/just/justfile;
  xdg.configFile."starship.toml".source = ../dotfiles/dot_config/starship.toml;
  xdg.configFile."wezterm".source = ../dotfiles/dot_config/wezterm;
  xdg.configFile."git".source = ../dotfiles/dot_config/git;
  home.file.".sbclrc".source = ../dotfiles/dot_sbclrc;
  home.file.".signature".source = ../dotfiles/dot_signature;

  home.file.".config/fish/functions" = {
    source = ../dotfiles/dot_config/fish/functions;
    recursive = true;
  };

  xdg.configFile."emacs".enable = false;
  home.file.".msmtprc".source = ../dotfiles/dot_msmtprc;
  home.file.".mbsyncrc".source = ../dotfiles/dot_mbsyncrc;

  home.file.".local/share/flf".source = ../dotfiles/dot_local/share/flf;
}
